<!DOCTYPE TS><TS>
<context>
    <name></name>
    <message>
        <source>UNKNOWN CUT</source>
        <translation type="obsolete">CONTEÚDO DESCONHECIDO</translation>
    </message>
</context>
<context>
    <name>@default</name>
    <message>
        <source>ALL</source>
        <translation type="obsolete">TODOS</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Couldn&apos;t initialize QSql driver!</source>
        <translation>Não foi possível inicializar driver QSql !</translation>
    </message>
    <message>
        <source>Couldn&apos;t open mySQL connection!</source>
        <translation>Não foi possível conetar ao mySQL !</translation>
    </message>
    <message>
        <source>Sequentially</source>
        <translation type="unfinished">Sequencialmente</translation>
    </message>
    <message>
        <source>Randomly</source>
        <translation type="unfinished">Randomicamente</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished">Desconhecido</translation>
    </message>
    <message>
        <source>Feature</source>
        <translation type="unfinished">Vários</translation>
    </message>
    <message>
        <source>Theme Open</source>
        <translation type="unfinished">Tema de Abertura</translation>
    </message>
    <message>
        <source>Theme Close</source>
        <translation type="unfinished">Tema de Fechamento</translation>
    </message>
    <message>
        <source>Theme Open/Close</source>
        <translation type="unfinished">Tema de Abertura/Fechamento</translation>
    </message>
    <message>
        <source>Background</source>
        <translation type="unfinished">BG</translation>
    </message>
    <message>
        <source>Commercial/Jingle/Promo</source>
        <translation type="unfinished">Comercial/Vinheta/Promo</translation>
    </message>
    <message>
        <source>UNKNOWN CUT</source>
        <translation type="unfinished">CONTEÚDO DESCONHECIDO</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation type="unfinished">Manual</translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished">Simples</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation type="unfinished">Sobre</translation>
    </message>
    <message>
        <source>Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Panel</source>
        <translation type="unfinished">Painel</translation>
    </message>
    <message>
        <source>Macro</source>
        <translation type="unfinished">Macro</translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation type="unfinished">SIMPLES<byte value="x9"/></translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation type="unfinished">SOBRE</translation>
    </message>
    <message>
        <source>STOP</source>
        <translation type="unfinished">PARE</translation>
    </message>
    <message>
        <source>UNKNOWN</source>
        <translation type="unfinished">DESCONHECIDO</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="unfinished">Áudio</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation type="unfinished">Marcador</translation>
    </message>
    <message>
        <source>Open Bracket</source>
        <translation type="unfinished">Abrir Colchetes</translation>
    </message>
    <message>
        <source>Close Bracket</source>
        <translation type="unfinished">FEchar Colchetes</translation>
    </message>
    <message>
        <source>ChainTo</source>
        <translation type="obsolete">Corrente para</translation>
    </message>
    <message>
        <source>Track</source>
        <translation type="unfinished">Pista</translation>
    </message>
    <message>
        <source>Link</source>
        <translation type="obsolete">Link</translation>
    </message>
    <message>
        <source>Traffic</source>
        <translation type="unfinished">Tráfego</translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="unfinished">Música</translation>
    </message>
    <message>
        <source>RDLogManager</source>
        <translation type="unfinished">RDControle</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation type="unfinished">Busca</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation type="unfinished">Gravação</translation>
    </message>
    <message>
        <source>Macro Event</source>
        <translation type="unfinished">Eventp Macro</translation>
    </message>
    <message>
        <source>Switch Event</source>
        <translation type="unfinished">Evento de Switch</translation>
    </message>
    <message>
        <source>Playout</source>
        <translation type="unfinished">Execução</translation>
    </message>
    <message>
        <source>Download</source>
        <translation type="unfinished">Download</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation type="unfinished">Upload</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Short Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Low Level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>High Level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Uploading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Server Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Internal Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Interrupted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Playing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Waiting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Device Busy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Such Cart/Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown Audio Format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CBSI DeltaFlex Traffic Reconciliation v2.01</source>
        <translation type="unfinished">CBSI DeltaFlex Traffic Reconciliation v2.01</translation>
    </message>
    <message>
        <source>Text Log</source>
        <translation type="unfinished">Texto</translation>
    </message>
    <message>
        <source>ASCAP/BMI Electronic Music Report</source>
        <translation type="unfinished">ASCAP/BMI Electronic Music Report</translation>
    </message>
    <message>
        <source>Technical Playout Report</source>
        <translation type="unfinished">Relatório Técnico de Execução</translation>
    </message>
    <message>
        <source>SoundExchange Statutory License Report</source>
        <translation type="unfinished">SoundExchange Statutory License Report</translation>
    </message>
    <message>
        <source>RadioTraffic.com Traffic Reconciliation</source>
        <translation type="unfinished">RadioTraffic.com Traffic Reconciliation</translation>
    </message>
    <message>
        <source>VisualTraffic Reconciliation</source>
        <translation type="unfinished">VisualTraffic Reconciliation</translation>
    </message>
    <message>
        <source>CounterPoint Traffic Reconciliation</source>
        <translation type="unfinished">CounterPoint Traffic Reconciliation</translation>
    </message>
    <message>
        <source>Music1 Reconciliation</source>
        <translation type="unfinished">Music1 Reconciliation</translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished">Outros</translation>
    </message>
    <message>
        <source>AM</source>
        <translation type="unfinished">AM</translation>
    </message>
    <message>
        <source>FM</source>
        <translation type="unfinished">FM</translation>
    </message>
    <message>
        <source>Report complete!</source>
        <translation type="unfinished">Relatório Completo</translation>
    </message>
    <message>
        <source>Report canceled!</source>
        <translation type="unfinished">Relatório Cancelado</translation>
    </message>
    <message>
        <source>Unable to open report file!</source>
        <translation type="unfinished">Não foi possível abrir o Relatório!</translation>
    </message>
    <message>
        <source>Music Summary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>WideOrbit Traffic Reconciliation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown Position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Top Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Top Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Top Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bottom Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bottom Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bottom Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NPR/DS SoundExchange Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Music Playout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Main Log Output 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Main Log Output 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound Panel First Play Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aux Log 1 Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aux Log 2 Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound Panel Second Play Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound Panel Third Play Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound Panel Fourth Play Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audition/Cue Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound Panel Fifth and Later Play Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>invalid SQL or failed DB connection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished">Todos</translation>
    </message>
    <message>
        <source>Relative</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NaturalLog Reconciliation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LiveAssist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Previous</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Classical Music Playout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>reserved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mr. Master Reconciliation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Spin Count</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>feature</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>promo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>cold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>fade</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NoTime</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MusicLink</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TrafficLink</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>new cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>cart</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDAddCart</name>
    <message>
        <source>&amp;Group:</source>
        <translation>&amp;Grupo:</translation>
    </message>
    <message>
        <source>&amp;New Cart Number:</source>
        <translation>&amp;Número:</translation>
    </message>
    <message>
        <source>&amp;New Cart Type:</source>
        <translation>&amp;Tipo:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Áudio</translation>
    </message>
    <message>
        <source>Macro</source>
        <translation>Macro</translation>
    </message>
    <message>
        <source>[new cart]</source>
        <translation>[novo cartão]</translation>
    </message>
    <message>
        <source>&amp;New Cart Title:</source>
        <translation>&amp;Título:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>No Available Cart Numbers</source>
        <translation>Não há Números de Cartões Disponíveis</translation>
    </message>
    <message>
        <source>There are no more available cart numbers for the group!</source>
        <translation>Não há mais números de Cartões disponíveis para este Grupo!</translation>
    </message>
    <message>
        <source>Invalid Number</source>
        <translation>Número Inválido</translation>
    </message>
    <message>
        <source>Invalid Cart Number!</source>
        <translation>Número de Cartão Inválido!</translation>
    </message>
    <message>
        <source>Title Required</source>
        <translation>O Título é necessário</translation>
    </message>
    <message>
        <source>You must enter a cart title!</source>
        <translation>Você deve dar um título ao cartão!</translation>
    </message>
    <message>
        <source>Duplicate Title</source>
        <translation>Título DUplicado</translation>
    </message>
    <message>
        <source>The cart title must be unique!</source>
        <translation>O Título do Cartão deve ser único!</translation>
    </message>
    <message>
        <source>The cart number is outside of the permitted range for this group!</source>
        <translation>O número do Cartão está fora da variação permitida para este Grupo!</translation>
    </message>
    <message>
        <source>Cart Exists</source>
        <translation>O Cartão Existe</translation>
    </message>
    <message>
        <source>This cart already exists.</source>
        <translation>Este Cartão já Existe.</translation>
    </message>
</context>
<context>
    <name>RDAddLog</name>
    <message>
        <source>Create Log</source>
        <translation>Criar Lista</translation>
    </message>
    <message>
        <source>&amp;New Log Name:</source>
        <translation>&amp;Nome da &amp;Lista:</translation>
    </message>
    <message>
        <source>&amp;Service:</source>
        <translation>&amp;Serviço</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>RDLogEdit</source>
        <translation>RDListas</translation>
    </message>
    <message>
        <source>The name is invalid!</source>
        <translation type="obsolete">O Nome é Inválido!</translation>
    </message>
    <message>
        <source>The service is invalid!</source>
        <translation>O Serviço é Inválido!</translation>
    </message>
</context>
<context>
    <name>RDAudioSettingsDialog</name>
    <message>
        <source>Edit Settings</source>
        <translation>Editar Configurações</translation>
    </message>
    <message>
        <source>Default &amp;Format:</source>
        <translation>&amp;Formato Padrão:</translation>
    </message>
    <message>
        <source>Default &amp;Channels:</source>
        <translation>&amp;Canais Padrão:</translation>
    </message>
    <message>
        <source>Default &amp;Sample Rate:</source>
        <translation>&amp;Taxa de Amostragem Padrão:</translation>
    </message>
    <message>
        <source>Default &amp;Bitrate:</source>
        <translation>&amp;Taxa de Bits Padrão:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>PCM16</source>
        <translation>PCM16</translation>
    </message>
    <message>
        <source>OggVorbis</source>
        <translation>OggVorbis</translation>
    </message>
    <message>
        <source>MPEG Layer 2</source>
        <translation>MPEG Layer 2</translation>
    </message>
    <message>
        <source>MPEG Layer 3</source>
        <translation>MPEG Layer 3</translation>
    </message>
</context>
<context>
    <name>RDButtonDialog</name>
    <message>
        <source>Edit Button</source>
        <translation>Editar Botão</translation>
    </message>
    <message>
        <source>Label:</source>
        <translation>Mostre:</translation>
    </message>
    <message>
        <source>Cart:</source>
        <translation>Cartão:</translation>
    </message>
    <message>
        <source>Set
Cart</source>
        <translation>Escolha
Cartão</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Limpar</translation>
    </message>
    <message>
        <source>Set
Color</source>
        <translation>Escolha
Cor</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>NOT FOUND</source>
        <translation>NÃO ENCONTRADO</translation>
    </message>
</context>
<context>
    <name>RDCardSelector</name>
    <message>
        <source>Card:</source>
        <translation>Placa:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Porta:</translation>
    </message>
</context>
<context>
    <name>RDCart</name>
    <message>
        <source>Sequentially</source>
        <translation type="obsolete">Sequencialmente</translation>
    </message>
    <message>
        <source>Randomly</source>
        <translation type="obsolete">Randomicamente</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="obsolete">Desconhecido</translation>
    </message>
    <message>
        <source>Feature</source>
        <translation type="obsolete">Vários</translation>
    </message>
    <message>
        <source>Theme Open</source>
        <translation type="obsolete">Tema de Abertura</translation>
    </message>
    <message>
        <source>Theme Close</source>
        <translation type="obsolete">Tema de Fechamento</translation>
    </message>
    <message>
        <source>Theme Open/Close</source>
        <translation type="obsolete">Tema de Abertura/Fechamento</translation>
    </message>
    <message>
        <source>Background</source>
        <translation type="obsolete">BG</translation>
    </message>
    <message>
        <source>Commercial/Jingle/Promo</source>
        <translation type="obsolete">Comercial/Vinheta/Promo</translation>
    </message>
</context>
<context>
    <name>RDCartDialog</name>
    <message>
        <source>Select Cart</source>
        <translation>Selecionar Cartão</translation>
    </message>
    <message>
        <source>Please Wait...</source>
        <translation>Por Favor, Espere...</translation>
    </message>
    <message>
        <source>Cart Filter:</source>
        <translation>Filtro:</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation>&amp;Procurar</translation>
    </message>
    <message>
        <source>C&amp;lear</source>
        <translation>&amp;Limpar</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Grupo:</translation>
    </message>
    <message>
        <source>NUMBER</source>
        <translation>NÚMERO</translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation>DURAÇÃO</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation>TÍTULO</translation>
    </message>
    <message>
        <source>ARTIST</source>
        <translation>ARTISTA</translation>
    </message>
    <message>
        <source>GROUP</source>
        <translation>GRUPO</translation>
    </message>
    <message>
        <source>CLIENT</source>
        <translation>CLIENTE</translation>
    </message>
    <message>
        <source>AGENCY</source>
        <translation>AGÊNCIA</translation>
    </message>
    <message>
        <source>USER DEF</source>
        <translation>USO GENERICO</translation>
    </message>
    <message>
        <source>START</source>
        <translation>INÍCIO</translation>
    </message>
    <message>
        <source>END</source>
        <translation>FINAL</translation>
    </message>
    <message>
        <source>Send to
&amp;Editor</source>
        <translation>Mandar ao
&amp;Editor</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>ALL</source>
        <translation>TODOS</translation>
    </message>
    <message>
        <source>Show Only First</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Matches</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scheduler Code:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load From
&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to create temporary cart for import!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to get temporary cart number for import!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Imported from</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Importing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>COMPOSER</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CONDUCTOR</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDCueEdit</name>
    <message>
        <source>&amp;Audition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End</source>
        <translation type="unfinished">Fim</translation>
    </message>
    <message>
        <source>&amp;Recue</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDCueEditDialog</name>
    <message>
        <source>Set Cue Point</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Cancelar</translation>
    </message>
</context>
<context>
    <name>RDCutDialog</name>
    <message>
        <source>Select Cut</source>
        <translation>Selecionar Conteúdo</translation>
    </message>
    <message>
        <source>Please Wait...</source>
        <translation>Por Favor, Espere...</translation>
    </message>
    <message>
        <source>Cart Filter:</source>
        <translation>Filtro de Cartões:</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation>&amp;Procurar</translation>
    </message>
    <message>
        <source>C&amp;lear</source>
        <translation>&amp;Limpar</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Grupo:</translation>
    </message>
    <message>
        <source>Carts</source>
        <translation>Cartão:</translation>
    </message>
    <message>
        <source>NUMBER</source>
        <translation>NÚMERO</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation>TÍTULO</translation>
    </message>
    <message>
        <source>GROUP</source>
        <translation>GRUPO</translation>
    </message>
    <message>
        <source>Cuts</source>
        <translation>Conteúdos</translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation>DESCRIÇÃO</translation>
    </message>
    <message>
        <source>&amp;Add New
Cart</source>
        <translation>&amp;Novo
Cartão</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Limpar</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>ALL</source>
        <translation>TODOS</translation>
    </message>
    <message>
        <source>Show Only First</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Matches</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scheduler Code:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDDateDialog</name>
    <message>
        <source>Select Date</source>
        <translation>Selecione Data</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
</context>
<context>
    <name>RDDatePicker</name>
    <message>
        <source>Mo</source>
        <translation>Seg</translation>
    </message>
    <message>
        <source>Tu</source>
        <translation>Ter</translation>
    </message>
    <message>
        <source>We</source>
        <translation>Qua</translation>
    </message>
    <message>
        <source>Th</source>
        <translation>Qui</translation>
    </message>
    <message>
        <source>Fr</source>
        <translation>Sex</translation>
    </message>
    <message>
        <source>Sa</source>
        <translation>Sab</translation>
    </message>
    <message>
        <source>Su</source>
        <translation>Dom</translation>
    </message>
</context>
<context>
    <name>RDEditAudio</name>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Salvar</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>Amplitude</source>
        <translation>Amplitude</translation>
    </message>
    <message>
        <source>Zoom
In</source>
        <translation>Zoom
In</translation>
    </message>
    <message>
        <source>Zoom
Out</source>
        <translation>Zoom
Out</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Tempo</translation>
    </message>
    <message>
        <source>Full
In</source>
        <translation>Zoom
Máximo</translation>
    </message>
    <message>
        <source>Full
Out</source>
        <translation>Zoom
Mínimo</translation>
    </message>
    <message>
        <source>Goto</source>
        <translation>Ir Até</translation>
    </message>
    <message>
        <source>Cursor</source>
        <translation>Cursor</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Casa</translation>
    </message>
    <message>
        <source>End</source>
        <translation>Fim</translation>
    </message>
    <message>
        <source>Cut
Start</source>
        <translation>Início</translation>
    </message>
    <message>
        <source>Cut
End</source>
        <translation>Fim</translation>
    </message>
    <message>
        <source>Talk
Start</source>
        <translation>Início
Locutor</translation>
    </message>
    <message>
        <source>Segue
Start</source>
        <translation>Sobre
Começa</translation>
    </message>
    <message>
        <source>Segue
End</source>
        <translation>Sobre
Termina</translation>
    </message>
    <message>
        <source>Fade
Up</source>
        <translation>Fade
Up</translation>
    </message>
    <message>
        <source>Hook
Start</source>
        <translation>Trecho
Começa</translation>
    </message>
    <message>
        <source>Hook
End</source>
        <translation>Trecho
Termina</translation>
    </message>
    <message>
        <source> dB</source>
        <translation> dB</translation>
    </message>
    <message>
        <source>Threshold</source>
        <translation>Valor Mínimo</translation>
    </message>
    <message>
        <source>Trim
Start</source>
        <translation>Corte
Começa</translation>
    </message>
    <message>
        <source>Trim
End</source>
        <translation>Corte
Termina</translation>
    </message>
    <message>
        <source>Cut Gain</source>
        <translation>Ganho</translation>
    </message>
    <message>
        <source>Remove
Marker</source>
        <translation>Remover
Marcador</translation>
    </message>
    <message>
        <source>No Fade on Segue Out</source>
        <translation>Sem Fade na Saída</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Posição</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Duração</translation>
    </message>
    <message>
        <source>Delete Talk Markers</source>
        <translation>Deletar Marcadores de Locução</translation>
    </message>
    <message>
        <source>Delete Segue Markers</source>
        <translation>Deletar Marcadores de Sobre</translation>
    </message>
    <message>
        <source>Delete Hook Markers</source>
        <translation>Deletar Marcadores de Trechos</translation>
    </message>
    <message>
        <source>Delete Fade Up Marker</source>
        <translation>Deletar Marcadores de Fade Up</translation>
    </message>
    <message>
        <source>Delete Fade Down Marker</source>
        <translation>Deletar Marcadores de Fade Down</translation>
    </message>
    <message>
        <source>dB</source>
        <translation>dB</translation>
    </message>
    <message>
        <source>&lt;none&gt;</source>
        <translation>&lt;nenhum&gt;</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Conteúdo</translation>
    </message>
    <message>
        <source>Talk</source>
        <translation>Fim Locutor</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <source>Hook</source>
        <translation>Trecho
</translation>
    </message>
    <message>
        <source>Fade Up</source>
        <translation>Fade Up</translation>
    </message>
    <message>
        <source>Fade Down</source>
        <translation>Fade Down</translation>
    </message>
    <message>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <source>Rivendell Web Service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to download peak data, error was:
&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Marker Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Less than half of the audio is playable with these marker settings.
Are you sure you want to save?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>More than half of the audio will be faded with these marker settings.
Are you sure you want to save?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDEditPanelName</name>
    <message>
        <source>Edit Panel Name</source>
        <translation>Editar nome do Painel</translation>
    </message>
    <message>
        <source>Panel &amp;Name:</source>
        <translation>&amp;Nome do Painel:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK
</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
</context>
<context>
    <name>RDExceptionDialog</name>
    <message>
        <source>Rivendell Exception Report</source>
        <translation>Relatório de Exceções do Rivendell</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Salvar</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <source>Text (*.txt *.TXT)
All Files (*.*)</source>
        <translation>Textos (*.txt *.TXT)
Todos os Arquivos (*.*)</translation>
    </message>
    <message>
        <source>Export File</source>
        <translation>Exportar Arquivo</translation>
    </message>
    <message>
        <source>The file</source>
        <translation>O Arquivo</translation>
    </message>
    <message>
        <source>already exists!
Overwrite?</source>
        <translation>já Existe! 
Sobreescrever?</translation>
    </message>
    <message>
        <source>File Exists</source>
        <translation>Arquivo Existente</translation>
    </message>
    <message>
        <source>Unable to open file</source>
        <translation>Não foi Possível abrir o arquivo</translation>
    </message>
    <message>
        <source>for writing!</source>
        <translation>para escrita!</translation>
    </message>
    <message>
        <source>File Error</source>
        <translation>Erro no Arquivo</translation>
    </message>
</context>
<context>
    <name>RDExportSettingsDialog</name>
    <message>
        <source>Edit Export Settings</source>
        <translation>Editar Configuração de Exportação</translation>
    </message>
    <message>
        <source>&amp;Channels:</source>
        <translation>&amp;Canais:</translation>
    </message>
    <message>
        <source>&amp;Sample Rate:</source>
        <translation>&amp;Taxa de Amostragem:</translation>
    </message>
    <message>
        <source>&amp;Bitrate:</source>
        <translation>&amp;Taxa de Bits:</translation>
    </message>
    <message>
        <source>&amp;Quality:</source>
        <translation>&amp;Qualidade:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>PCM16</source>
        <translation>PCM16</translation>
    </message>
    <message>
        <source>FLAC</source>
        <translation>FLAC</translation>
    </message>
    <message>
        <source>MPEG Layer 2</source>
        <translation>MPEG Layer 2</translation>
    </message>
    <message>
        <source>MPEG Layer 3</source>
        <translation>MPEG Layer 3</translation>
    </message>
    <message>
        <source>OggVorbis</source>
        <translation>OggVorbis</translation>
    </message>
    <message>
        <source>VBR</source>
        <translation>VBR</translation>
    </message>
    <message>
        <source>32 kbps</source>
        <translation>32 kbps</translation>
    </message>
    <message>
        <source>64 kbps</source>
        <translation>64 kbps</translation>
    </message>
    <message>
        <source>96 kbps</source>
        <translation>96 kbps</translation>
    </message>
    <message>
        <source>128 kbps</source>
        <translation>128 kbps</translation>
    </message>
    <message>
        <source>160 kbps</source>
        <translation>160 kbps</translation>
    </message>
    <message>
        <source>192 kbps</source>
        <translation>192 kbps</translation>
    </message>
    <message>
        <source>224 kbps</source>
        <translation>224 kbps</translation>
    </message>
    <message>
        <source>256 kbps</source>
        <translation>256 kbps</translation>
    </message>
    <message>
        <source>288 kbps</source>
        <translation>288 kbps</translation>
    </message>
    <message>
        <source>320 kbps</source>
        <translation>320 kbps</translation>
    </message>
    <message>
        <source>352 kbps</source>
        <translation>352 kbps</translation>
    </message>
    <message>
        <source>384 kbps</source>
        <translation>384 kbps</translation>
    </message>
    <message>
        <source>416 kbps</source>
        <translation>416 kbps</translation>
    </message>
    <message>
        <source>448 kbps</source>
        <translation>448 kbps</translation>
    </message>
    <message>
        <source>48 kbps</source>
        <translation>48 kbps</translation>
    </message>
    <message>
        <source>56 kbps</source>
        <translation>56 kbps</translation>
    </message>
    <message>
        <source>80 kbps</source>
        <translation>80 kbps</translation>
    </message>
    <message>
        <source>112 kbps</source>
        <translation>112 kbps</translation>
    </message>
    <message>
        <source>40 kbps</source>
        <translation>40 kbps</translation>
    </message>
    <message>
        <source>8 kbps</source>
        <translation>8 kbps</translation>
    </message>
    <message>
        <source>16 kbps</source>
        <translation>16 kbps</translation>
    </message>
    <message>
        <source>24 kbps</source>
        <translation>24 kbps</translation>
    </message>
    <message>
        <source>144 kbps</source>
        <translation>144 kbps</translation>
    </message>
    <message>
        <source>PCM24</source>
        <translation type="unfinished">PCM24</translation>
    </message>
</context>
<context>
    <name>RDGetAth</name>
    <message>
        <source>Enter ATH</source>
        <translation>Digitare ATH</translation>
    </message>
    <message>
        <source>Enter the agreggate tuning hours (ATH)
figure for the report period.
(Supplied by your streaming provider).</source>
        <translation>Digitar a figura de &apos;agreggate tuning hours (ATH)&apos;
para o período do relatório
(Disponibilizado pelo Servidor de Streaming).</translation>
    </message>
    <message>
        <source>ATH:</source>
        <translation>ATH:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>Invalid ATH</source>
        <translation>ATH Inválido</translation>
    </message>
    <message>
        <source>You must provide a valid ATH figure!</source>
        <translation>Você deve dar uma figura de ATH válida!</translation>
    </message>
</context>
<context>
    <name>RDGetPasswd</name>
    <message>
        <source>Enter Password</source>
        <translation>Digitar Senha</translation>
    </message>
    <message>
        <source>Enter password</source>
        <translation>Digitar Senha</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
</context>
<context>
    <name>RDGpioSelector</name>
    <message>
        <source>Pin:</source>
        <translation>Pin:</translation>
    </message>
</context>
<context>
    <name>RDImportAudio</name>
    <message>
        <source>Import/Export Audio File</source>
        <translation>Importar/Exportar Arquivo de Áudio</translation>
    </message>
    <message>
        <source>Import File</source>
        <translation>Importar Arquivo</translation>
    </message>
    <message>
        <source>Filename:</source>
        <translation>Arquivo:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Selecionar</translation>
    </message>
    <message>
        <source>Import file metadata</source>
        <translation>Importar metadados do arquivo</translation>
    </message>
    <message>
        <source>Channels:</source>
        <translation>Canais:</translation>
    </message>
    <message>
        <source>Autotrim</source>
        <translation>AutoCorte</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Nível:</translation>
    </message>
    <message>
        <source>dBFS</source>
        <translation>dBFS</translation>
    </message>
    <message>
        <source>Export File</source>
        <translation>Exportar Arquivo</translation>
    </message>
    <message>
        <source>Export file metadata</source>
        <translation>Exportar matadados do arquivo</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Formato:</translation>
    </message>
    <message>
        <source>S&amp;et</source>
        <translation>&amp;Selecionar</translation>
    </message>
    <message>
        <source>Normalize</source>
        <translation>Normalizar</translation>
    </message>
    <message>
        <source>&amp;Import</source>
        <translation>&amp;Importar</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importar</translation>
    </message>
    <message>
        <source>Import Audio File</source>
        <translation>Importar Arquivo de Áudio</translation>
    </message>
    <message>
        <source>File does not exist!</source>
        <translation>Arquivo não existe!</translation>
    </message>
    <message>
        <source>Cannot open file!</source>
        <translation type="obsolete">Não foi possível abrir o arquivo!</translation>
    </message>
    <message>
        <source>Unsupported file type!</source>
        <translation type="obsolete">Tipo de Arquivo sem suporte!</translation>
    </message>
    <message>
        <source>Audio Exists</source>
        <translation type="obsolete">Áudio Existe</translation>
    </message>
    <message>
        <source>This will overwrite the existing recording.
Do you want to proceed?</source>
        <translation type="obsolete">Isto sobreescreverá a gravação existente.
Você quer continuar?</translation>
    </message>
    <message>
        <source>Empty Clipboard</source>
        <translation type="obsolete">Clipboard Vazio</translation>
    </message>
    <message>
        <source>Importing this cut will also empty the clipboard.
Do you still want to proceed?</source>
        <translation type="obsolete">Importar este Conteúdo também esvaziará o clipboard. 
Você quer continuar?</translation>
    </message>
    <message>
        <source>Import Complete</source>
        <translation>Importação Completa</translation>
    </message>
    <message>
        <source>Import complete!</source>
        <translation>Importação Completa!</translation>
    </message>
    <message>
        <source>Import Aborted</source>
        <translation type="obsolete">Importação Abortada</translation>
    </message>
    <message>
        <source>The import has been aborted.</source>
        <translation type="obsolete">A Importação foi abortada.</translation>
    </message>
    <message>
        <source>Import Failed</source>
        <translation type="obsolete">Importação Falhou</translation>
    </message>
    <message>
        <source>The importer encountered an error.
Please check your importer configuration and try again.</source>
        <translation type="obsolete">O importador encontrou um erro.
Por Favor, cheque suas configurações e tenbte outra vez.</translation>
    </message>
    <message>
        <source>File Exists</source>
        <translation>Arquivo Existente</translation>
    </message>
    <message>
        <source>The selected file already exists!
Do you want to overwrite it?</source>
        <translation>O arquivo selecionado já existe!
Você quer sobreescrevê-lo?</translation>
    </message>
    <message>
        <source>File Error</source>
        <translation type="obsolete">Erro no Arquivo</translation>
    </message>
    <message>
        <source>Cannot open file in archive!</source>
        <translation type="obsolete">Não foi possível abrir arquivo no Acervo!</translation>
    </message>
    <message>
        <source>Unsupported file type in archive!</source>
        <translation type="obsolete">Arquivo sem Suporte no Acervo!</translation>
    </message>
    <message>
        <source>No Access</source>
        <translation type="obsolete">Sem Acesso</translation>
    </message>
    <message>
        <source>Unable to open the file for writing!</source>
        <translation type="obsolete">Não foi possível abrir o arquivo para escrita!</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="obsolete">OK</translation>
    </message>
    <message>
        <source>Export Complete</source>
        <translation>Exportação Completa</translation>
    </message>
    <message>
        <source>Export complete!</source>
        <translation>Exportação Completa!</translation>
    </message>
    <message>
        <source>Export Aborted</source>
        <translation type="obsolete">Exportação Abortada</translation>
    </message>
    <message>
        <source>The export has been aborted.</source>
        <translation type="obsolete">A Exportação foi abortada.</translation>
    </message>
    <message>
        <source>Export Failed</source>
        <translation type="obsolete">Exportação Falhou</translation>
    </message>
    <message>
        <source>The Exporter encountered an error.
Please check your configuration and try again.</source>
        <translation type="obsolete">O Exportador encontrou um erro.
Por Favor, cheque suas configurações e tenbte outra vez.</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDIntegerDialog</name>
    <message>
        <source>Set Value</source>
        <translation>Selecionar Valor</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
</context>
<context>
    <name>RDIntegerEdit</name>
    <message>
        <source>Set Value</source>
        <translation>Selecionar Valor</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Adicionar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Deletar</translation>
    </message>
</context>
<context>
    <name>RDLicense</name>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <source>GNU Public License v2</source>
        <translation>GNU Public License v2</translation>
    </message>
</context>
<context>
    <name>RDListGroups</name>
    <message>
        <source>Select Group</source>
        <translation>Selecionar Grupo</translation>
    </message>
    <message>
        <source>NAME</source>
        <translation>NOME</translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation>DESCRIÇÃO</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
</context>
<context>
    <name>RDListLogs</name>
    <message>
        <source>Select Log - User: </source>
        <translation>Selecionar Lista - Usuario: </translation>
    </message>
    <message>
        <source>Select Log</source>
        <translation>Selecione Lista</translation>
    </message>
    <message>
        <source>NAME</source>
        <translation>NOME</translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation>DESCRIÇÃO</translation>
    </message>
    <message>
        <source>SERVICE</source>
        <translation>SERVIÇO</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>RDListSelector</name>
    <message>
        <source>Available Services</source>
        <translation>Serviços Disponíveis</translation>
    </message>
    <message>
        <source>Add &gt;&gt;</source>
        <translation>Add &gt;&gt;</translation>
    </message>
    <message>
        <source>&lt;&lt; Remove</source>
        <translation>&lt;&lt; Remover
</translation>
    </message>
    <message>
        <source>Active Services</source>
        <translation>Serviços Ativos</translation>
    </message>
</context>
<context>
    <name>RDLogLine</name>
    <message>
        <source>Unknown</source>
        <translation type="obsolete">Desconhecido</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation type="obsolete">Manual</translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="obsolete">Simples</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation type="obsolete">Sobre</translation>
    </message>
    <message>
        <source>Time</source>
        <translation type="obsolete">Hora</translation>
    </message>
    <message>
        <source>Panel</source>
        <translation type="obsolete">Painel</translation>
    </message>
    <message>
        <source>Macro</source>
        <translation type="obsolete">Macro</translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation type="obsolete">SIMPLES<byte value="x9"/></translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation type="obsolete">SOBRE</translation>
    </message>
    <message>
        <source>STOP</source>
        <translation type="obsolete">PARE</translation>
    </message>
    <message>
        <source>UNKNOWN</source>
        <translation type="obsolete">DESCONHECIDO</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="obsolete">Áudio</translation>
    </message>
    <message>
        <source>Marker</source>
        <translation type="obsolete">Marcador</translation>
    </message>
    <message>
        <source>Open Bracket</source>
        <translation type="obsolete">Abrir Colchetes</translation>
    </message>
    <message>
        <source>Close Bracket</source>
        <translation type="obsolete">FEchar Colchetes</translation>
    </message>
    <message>
        <source>ChainTo</source>
        <translation type="obsolete">Corrente para</translation>
    </message>
    <message>
        <source>Track</source>
        <translation type="obsolete">Pista</translation>
    </message>
    <message>
        <source>Link</source>
        <translation type="obsolete">Link</translation>
    </message>
    <message>
        <source>Traffic</source>
        <translation type="obsolete">Tráfego</translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="obsolete">Música</translation>
    </message>
    <message>
        <source>RDLogManager</source>
        <translation type="obsolete">RDControle</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation type="obsolete">Busca</translation>
    </message>
</context>
<context>
    <name>RDPanelButton</name>
    <message>
        <source>No Audio</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDPasswd</name>
    <message>
        <source>Change Password</source>
        <translation>Alterar Senha</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>&amp;Password:</source>
        <translation>&amp;Senha:</translation>
    </message>
    <message>
        <source>C&amp;onfirm:</source>
        <translation>&amp;Confirmar</translation>
    </message>
    <message>
        <source>Password Mismatch</source>
        <translation>Senha não bateu</translation>
    </message>
    <message>
        <source>The passwords don&apos;t match,
please try again!</source>
        <translation>As Senhas não batem,
por favor, tente novamente!</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>RDRecording</name>
    <message>
        <source>Recording</source>
        <translation type="obsolete">Gravação</translation>
    </message>
    <message>
        <source>Macro Event</source>
        <translation type="obsolete">Eventp Macro</translation>
    </message>
    <message>
        <source>Switch Event</source>
        <translation type="obsolete">Evento de Switch</translation>
    </message>
    <message>
        <source>Playout</source>
        <translation type="obsolete">Execução</translation>
    </message>
    <message>
        <source>Download</source>
        <translation type="obsolete">Download</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation type="obsolete">Upload</translation>
    </message>
</context>
<context>
    <name>RDRehash</name>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>Internal Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDXport service returned an error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid user or password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio does not exist</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RDReport</name>
    <message>
        <source>CBSI DeltaFlex Traffic Reconciliation v2.01</source>
        <translation type="obsolete">CBSI DeltaFlex Traffic Reconciliation v2.01</translation>
    </message>
    <message>
        <source>Text Log</source>
        <translation type="obsolete">Texto</translation>
    </message>
    <message>
        <source>ASCAP/BMI Electronic Music Report</source>
        <translation type="obsolete">ASCAP/BMI Electronic Music Report</translation>
    </message>
    <message>
        <source>Technical Playout Report</source>
        <translation type="obsolete">Relatório Técnico de Execução</translation>
    </message>
    <message>
        <source>SoundExchange Statutory License Report</source>
        <translation type="obsolete">SoundExchange Statutory License Report</translation>
    </message>
    <message>
        <source>RadioTraffic.com Traffic Reconciliation</source>
        <translation type="obsolete">RadioTraffic.com Traffic Reconciliation</translation>
    </message>
    <message>
        <source>VisualTraffic Reconciliation</source>
        <translation type="obsolete">VisualTraffic Reconciliation</translation>
    </message>
    <message>
        <source>CounterPoint Traffic Reconciliation</source>
        <translation type="obsolete">CounterPoint Traffic Reconciliation</translation>
    </message>
    <message>
        <source>Music1 Reconciliation</source>
        <translation type="obsolete">Music1 Reconciliation</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="obsolete">Desconhecido</translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="obsolete">Outros</translation>
    </message>
    <message>
        <source>AM</source>
        <translation type="obsolete">AM</translation>
    </message>
    <message>
        <source>FM</source>
        <translation type="obsolete">FM</translation>
    </message>
    <message>
        <source>Report complete!</source>
        <translation type="obsolete">Relatório Completo</translation>
    </message>
    <message>
        <source>Report canceled!</source>
        <translation type="obsolete">Relatório Cancelado</translation>
    </message>
    <message>
        <source>Unable to open report file!</source>
        <translation type="obsolete">Não foi possível abrir o Relatório!</translation>
    </message>
</context>
<context>
    <name>RDSoundPanel</name>
    <message>
        <source>Play All</source>
        <translation>Tocar Tudo</translation>
    </message>
    <message>
        <source>Play Hook</source>
        <translation>Tocar Trecho</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Todos</translation>
    </message>
    <message>
        <source>Setup</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>Cart</source>
        <translation>Cartão</translation>
    </message>
    <message>
        <source>Panel</source>
        <translation>Painel</translation>
    </message>
</context>
<context>
    <name>RDSqlDatabaseStatus</name>
    <message>
        <source>Database connection restored.</source>
        <translation>Conexão à Base de Daods reestabelecido.</translation>
    </message>
    <message>
        <source>Database connection failed : </source>
        <translation>Conexão à Base de Daods falhou: </translation>
    </message>
</context>
<context>
    <name>RDStereoMeter</name>
    <message>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <source>CLIP</source>
        <translation>CLIP</translation>
    </message>
</context>
<context>
    <name>RDSvc</name>
    <message>
        <source>The following events were not placed:
</source>
        <translation>Os seguintes Eventos não foram colocados:
</translation>
    </message>
    <message>
        <source>[unknown cart]</source>
        <translation>[cartão desconhecido]</translation>
    </message>
    <message>
        <source>Event Fill Errors
</source>
        <translation>Erros de Auto Preenchimento
</translation>
    </message>
</context>
</TS>
